import { PromiseHandler, LoggerWrapper, ILogger, ExtendedError, ObservableData, LoadableEvent } from '@ts-core/common';
import { Network, Contract, Wallet, Gateway } from 'fabric-network';
import { Channel } from 'fabric-common';
import { Subject } from 'rxjs';
import { Block } from './Block';
import { IFabricBlock } from './IFabricBlock';
import { IFabricConnectionSettings } from './IFabricConnectionSettings';
import { IFabricConnection } from './IFabricConnection';
import { FabricContractQSCC } from './contract/FabricContractQSCC';
export declare class FabricApiClient extends LoggerWrapper {
    protected settings: IFabricConnectionSettings;
    static parseBlock(block: Block): IFabricBlock;
    static getBlockDate(block: Block): Date;
    static createConnection(settings: IFabricConnectionSettings, wallet?: Wallet): Promise<IFabricConnection>;
    static createWallet(settings: IFabricConnectionSettings): Promise<Wallet>;
    protected observer: Subject<ObservableData<LoadableEvent, any>>;
    protected connectionPromise: PromiseHandler<void, ExtendedError>;
    protected _connection: IFabricConnection;
    protected _qsccContract: FabricContractQSCC;
    protected _isConnected: boolean;
    constructor(logger: ILogger, settings: IFabricConnectionSettings);
    connect(): Promise<void>;
    disconnect(error?: ExtendedError): void;
    destroy(): void;
    protected reconnect(): Promise<void>;
    protected connectCompleteHandler(): void;
    protected connectErrorHandler(error?: ExtendedError): void;
    get connection(): IFabricConnection;
    set connection(value: IFabricConnection);
    get isConnected(): boolean;
    get network(): Network;
    get channel(): Channel;
    get contract(): Contract;
    get gateway(): Gateway;
    get qsccContract(): FabricContractQSCC;
}
