"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FabricContractQSCC = void 0;
const FabricApiClient_1 = require("../FabricApiClient");
const FabricContract_1 = require("./FabricContract");
const FabricUtil_1 = require("../FabricUtil");
const fabric_protos_1 = require("fabric-protos");
const index_js_1 = require("fabric-common/index.js");
const _ = require("lodash");
class FabricContractQSCC extends FabricContract_1.FabricContract {
    constructor(api) {
        super('qscc', api);
    }
    parseBlock(data) {
        return FabricApiClient_1.FabricApiClient.parseBlock(index_js_1.BlockDecoder.decode(data));
    }
    parseTransaction(data) {
        return index_js_1.BlockDecoder.decodeTransaction(data);
    }
    getInfo(channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let buffer = yield this.contract.evaluateTransaction('GetChainInfo', channel.name);
            let item = fabric_protos_1.common.BlockchainInfo.decode(buffer);
            return {
                height: FabricUtil_1.FabricUtil.fromLong(item.height),
                currentBlockHash: FabricUtil_1.FabricUtil.fromUintArray(item.currentBlockHash),
                previousBlockHash: FabricUtil_1.FabricUtil.fromUintArray(item.previousBlockHash)
            };
        });
    }
    getBlockNumber(channel) {
        return __awaiter(this, void 0, void 0, function* () {
            let info = yield this.getInfo(channel);
            return info.height;
        });
    }
    getBlock(block, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = null;
            if (_.isString(block)) {
                item = yield this.contract.evaluateTransaction('GetBlockByHash', channel.name, Buffer.from(block.toString(), 'hex'));
            }
            else {
                item = yield this.contract.evaluateTransaction('GetBlockByNumber', channel.name, block);
            }
            return this.parseBlock(item);
        });
    }
    getBlockByTransactionId(id, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = yield this.contract.evaluateTransaction('GetBlockByTxID', channel.name, id);
            return this.parseBlock(item);
        });
    }
    getTransaction(id, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = yield this.contract.evaluateTransaction('GetTransactionByID', channel.name, id);
            return this.parseTransaction(item);
        });
    }
}
exports.FabricContractQSCC = FabricContractQSCC;
