"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FabricConnectionSettingsFactory = void 0;
const common_1 = require("@ts-core/common");
const _ = require("lodash");
const common_2 = require("@ts-core/common");
const common_3 = require("@ts-core/common");
const FabricConnectionFileParser_1 = require("../parser/FabricConnectionFileParser");
class FabricConnectionSettingsFactory extends common_1.LoggerWrapper {
    constructor(logger) {
        super(logger);
        this._items = this.createCollection();
    }
    createCollection() {
        return new common_2.MapCollection('uid');
    }
    parseItem(item) {
        item.fabricIdentityPrivateKey = this.parsePem(item.fabricIdentityPrivateKey);
        item.fabricIdentityCertificate = this.parsePem(item.fabricIdentityCertificate);
        item.fabricTlsIdentityPrivateKey = this.parsePem(item.fabricTlsIdentityPrivateKey);
        item.fabricTlsIdentityCertificate = this.parsePem(item.fabricTlsIdentityCertificate);
        return item;
    }
    parsePem(item) {
        if (_.isNil(item)) {
            return null;
        }
        if (FabricConnectionFileParser_1.FabricConnectionFileParser.isPemFormat(item)) {
            return common_3.AbstractSettingsStorage.parsePEM(item);
        }
        return FabricConnectionFileParser_1.FabricConnectionFileParser.pemToOneLine(FabricConnectionFileParser_1.FabricConnectionFileParser.load(item));
    }
    isItemValid(item) {
        if (_.isNil(item)) {
            this.logger.warn(`Settings is nil`);
            return false;
        }
        if (_.isNil(item.uid)) {
            this.logger.warn(`Settings \"uid"\ nil`);
            return false;
        }
        return true;
    }
    get(uid) {
        return this.items.get(uid);
    }
    parse(items) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isEmpty(items)) {
                return;
            }
            items = _.compact(items);
            for (let item of items) {
                item = this.parseItem(item);
                if (this.isItemValid(item)) {
                    this.items.add(item);
                }
            }
        });
    }
    destroy() {
        if (this.isDestroyed) {
            return;
        }
        super.destroy();
        this.items.destroy();
        this._items = null;
    }
    get items() {
        return this._items;
    }
}
exports.FabricConnectionSettingsFactory = FabricConnectionSettingsFactory;
