"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FabricConnectionFileParser = void 0;
const common_1 = require("@ts-core/common");
const _ = require("lodash");
const fs = require("fs");
class FabricConnectionFileParser extends common_1.LoggerWrapper {
    static load(path, encoding = 'utf8') {
        return fs.readFileSync(path, { encoding });
    }
    static pemToOneLine(item) {
        item = JSON.stringify(item);
        return common_1.AbstractSettingsStorage.parsePEM(item.substr(1, item.length - 2));
    }
    static isPemFormat(item) {
        return !_.isNil(item) ? item.indexOf('-----') === 0 : false;
    }
    constructor(logger) {
        super(logger);
    }
    certsPathsToPem(file, isNeedRemovePath = true) {
        for (let name of ['peers', 'orderers']) {
            let section = file[name];
            if (_.isNil(section)) {
                continue;
            }
            for (let key in section) {
                let item = file[name][key];
                if (!_.isNil(item) && !_.isNil(item.tlsCACerts)) {
                    this.setPemToCert(item.tlsCACerts, isNeedRemovePath);
                }
            }
        }
        return file;
    }
    setPemToCert(item, isNeedRemovePath) {
        if (!_.isNil(item.pem) || _.isNil(item.path)) {
            return;
        }
        try {
            item.pem = FabricConnectionFileParser.pemToOneLine(FabricConnectionFileParser.load(item.path));
            if (isNeedRemovePath) {
                delete item.path;
            }
        }
        catch (_a) {
            this.warn(`Unable to load file from "${item.path}"`);
        }
    }
}
exports.FabricConnectionFileParser = FabricConnectionFileParser;
