var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { FabricApiClient } from '../FabricApiClient';
import { FabricContract } from './FabricContract';
import { FabricUtil } from '../FabricUtil';
import { common as FabricProtoCommon } from 'fabric-protos';
import { BlockDecoder } from 'fabric-common/index.js';
import * as _ from 'lodash';
export class FabricContractQSCC extends FabricContract {
    constructor(api) {
        super('qscc', api);
    }
    parseBlock(data) {
        return FabricApiClient.parseBlock(BlockDecoder.decode(data));
    }
    parseTransaction(data) {
        return BlockDecoder.decodeTransaction(data);
    }
    getInfo(channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let buffer = yield this.contract.evaluateTransaction('GetChainInfo', channel.name);
            let item = FabricProtoCommon.BlockchainInfo.decode(buffer);
            return {
                height: FabricUtil.fromLong(item.height),
                currentBlockHash: FabricUtil.fromUintArray(item.currentBlockHash),
                previousBlockHash: FabricUtil.fromUintArray(item.previousBlockHash)
            };
        });
    }
    getBlockNumber(channel) {
        return __awaiter(this, void 0, void 0, function* () {
            let info = yield this.getInfo(channel);
            return info.height;
        });
    }
    getBlock(block, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = null;
            if (_.isString(block)) {
                item = yield this.contract.evaluateTransaction('GetBlockByHash', channel.name, Buffer.from(block.toString(), 'hex'));
            }
            else {
                item = yield this.contract.evaluateTransaction('GetBlockByNumber', channel.name, block);
            }
            return this.parseBlock(item);
        });
    }
    getBlockByTransactionId(id, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = yield this.contract.evaluateTransaction('GetBlockByTxID', channel.name, id);
            return this.parseBlock(item);
        });
    }
    getTransaction(id, channel) {
        return __awaiter(this, void 0, void 0, function* () {
            if (_.isNil(channel)) {
                channel = this.api.channel;
            }
            let item = yield this.contract.evaluateTransaction('GetTransactionByID', channel.name, id);
            return this.parseTransaction(item);
        });
    }
}
